| Title: | Extension to the 'Lolog' Package for 'Triadic' Network Statistics |
|---|---|
| Description: | Provides an extension to the 'lolog' package by introducing the minTriadicClosure() statistic to capture higher-order interactions among triplets of nodes. This function facilitates improved modelling of group formations and 'triadic' closure in networks. A smoothing parameter has been incorporated to avoid numerical errors. |
| Authors: | Lekshmy Hema Nair [aut, cre] |
| Maintainer: | Lekshmy Hema Nair <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 1.0.0 |
| Built: | 2026-05-20 07:26:25 UTC |
| Source: | https://github.com/cran/MinTriadic |
A smoothed triadic‐closure statistic for LOLOG models.
minTriadicClosure(triadDegree, smoothing_k = 1)minTriadicClosure(triadDegree, smoothing_k = 1)
triadDegree |
Integer threshold for triangle count. |
smoothing_k |
Numeric smoothing parameter. |
Returns a registered LOLOG change statistic that smoothly counts how many nodes are in at least 'triadDegree' triangles, using a smoothing parameter.
A LOLOG change statistic object.
registerMinTriadicClosure() # call once to register the C++ class stat <- minTriadicClosure(2, 1.5) print(stat)registerMinTriadicClosure() # call once to register the C++ class stat <- minTriadicClosure(2, 1.5) print(stat)