Welcome to ClientVPS Mirrors

Help for package MinTriadic
Type: Package
Title: Extension to the 'Lolog' Package for 'Triadic' Network Statistics
Version: 1.0.0
Date: 2025-06-08
Description: Provides an extension to the 'lolog' package by introducing the minTriadicClosure() statistic to capture higher-order interactions among triplets of nodes. This function facilitates improved modelling of group formations and 'triadic' closure in networks. A smoothing parameter has been incorporated to avoid numerical errors.
License: GPL (≥ 3)
Imports: Rcpp (≥ 0.10.0), lolog
Suggests: network, rmarkdown, knitr, sna, testthat
LinkingTo: Rcpp, lolog, BH
NeedsCompilation: yes
Encoding: UTF-8
Packaged: 2025-06-18 19:35:27 UTC; 22080824
RoxygenNote: 7.3.2
VignetteBuilder: knitr
Author: Lekshmy Hema Nair [aut, cre]
Maintainer: Lekshmy Hema Nair <lekshmyrohit25@gmail.com>
Repository: CRAN
Date/Publication: 2025-06-23 10:30:05 UTC

minTriadicClosure

Description

A smoothed triadic‐closure statistic for LOLOG models.

Usage

minTriadicClosure(triadDegree, smoothing_k = 1)

Arguments

triadDegree

Integer threshold for triangle count.

smoothing_k

Numeric smoothing parameter.

Details

Returns a registered LOLOG change statistic that smoothly counts how many nodes are in at least 'triadDegree' triangles, using a smoothing parameter.

Value

A LOLOG change statistic object.

Examples

registerMinTriadicClosure()  # call once to register the C++ class
stat <- minTriadicClosure(2, 1.5)
print(stat)


Register MinTriadicClosure Statistic (Internal)

Description

This function registers the MinTriadicClosure statistic for internal use. The actual registration happens in C++ and the package's '.onLoad' hook.

Usage

registerMinTriadicClosure()

Value

invisible NULL

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.